@@ -13,14 +13,14 @@ apply {{dir} {
 	set libraryfile [file join $::env(TDBC_LIBRARY) tdbc.tcl]
     }
     if {[package vsatisfies [package provide Tcl] 9.0-]} {
-	package ifneeded tdbc 1.1.5 \
+	package ifneeded tdbc 1.1.10 \
 		"package require TclOO;\
-		[list load [file join $dir libtcl9tdbc115.so.0.0] [string totitle tdbc]]\;\
-		[list source $libraryfile]"
+		[list load [file join $dir libtcl9tdbc1110.so.0.0] [string totitle tdbc]]\;\
+		[list source -encoding utf-8 $libraryfile]"
     } else {
-	package ifneeded tdbc 1.1.5 \
+	package ifneeded tdbc 1.1.10 \
 		"package require TclOO;\
-		[list load [file join $dir .. .. libtdbc115.so.0.0] [string totitle tdbc]]\;\
-		[list source $libraryfile]"
+		[list load [file join $dir .. .. libtdbc1110.so.0.0] [string totitle tdbc]]\;\
+		[list source -encoding utf-8 $libraryfile]"
     }
 }} $dir
